#[derive(Shape)]
{
// Attributes available to this derive:
#[written]
}
States ShapeOf for a layout, reading its members and their names from the type.
#[derive(Shape)]
{
// Attributes available to this derive:
#[written]
}
States ShapeOf for a layout, reading its members and their names from the type.