pub trait ShapeTaggedExt<This>{
// Required methods
fn sum_external<'w>(
&self,
alternatives: Vec<(Words<'w>, This::Ty)>,
) -> This::Ty;
fn sum_internal<'w>(
&self,
tag: Words<'w>,
alternatives: Vec<(Words<'w>, This::Ty)>,
) -> This::Ty;
fn sum_adjacent<'w>(
&self,
tag: Words<'w>,
content: Words<'w>,
alternatives: Vec<(Words<'w>, This::Ty)>,
) -> This::Ty;
}Expand description
The encodings of a choice that state a discriminant, which is what needs a member to state it in.
Required Methods
Sourcefn sum_external<'w>(&self, alternatives: Vec<(Words<'w>, This::Ty)>) -> This::Ty
fn sum_external<'w>(&self, alternatives: Vec<(Words<'w>, This::Ty)>) -> This::Ty
A choice written as one object per alternative, keyed by its name.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<This> ShapeTaggedExt<This> for This
The encodings of a choice that state a discriminant, which is what needs a member to state it in.